@@ -25,38 +25,34 @@ class SetLiveStreamsNotifyUrlConfigRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'live', '2016-11-01', 'SetLiveStreamsNotifyUrlConfig','live')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_NotifyReqAuth(self):
+	def get_NotifyReqAuth(self): # String
 		return self.get_query_params().get('NotifyReqAuth')
 
-	def set_NotifyReqAuth(self,NotifyReqAuth):
-		self.add_query_param('NotifyReqAuth',NotifyReqAuth)
-
-	def get_NotifyUrl(self):
+	def set_NotifyReqAuth(self, NotifyReqAuth):  # String
+		self.add_query_param('NotifyReqAuth', NotifyReqAuth)
+	def get_NotifyUrl(self): # String
 		return self.get_query_params().get('NotifyUrl')
 
-	def set_NotifyUrl(self,NotifyUrl):
-		self.add_query_param('NotifyUrl',NotifyUrl)
-
-	def get_DomainName(self):
+	def set_NotifyUrl(self, NotifyUrl):  # String
+		self.add_query_param('NotifyUrl', NotifyUrl)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_OwnerId(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_OwnerId(self): # Long
 		return self.get_query_params().get('OwnerId')
 
-	def set_OwnerId(self,OwnerId):
-		self.add_query_param('OwnerId',OwnerId)
-
-	def get_NotifyAuthKey(self):
+	def set_OwnerId(self, OwnerId):  # Long
+		self.add_query_param('OwnerId', OwnerId)
+	def get_NotifyAuthKey(self): # String
 		return self.get_query_params().get('NotifyAuthKey')
 
-	def set_NotifyAuthKey(self,NotifyAuthKey):
-		self.add_query_param('NotifyAuthKey',NotifyAuthKey)
\ No newline at end of file
+	def set_NotifyAuthKey(self, NotifyAuthKey):  # String
+		self.add_query_param('NotifyAuthKey', NotifyAuthKey)
